# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lakeside.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='lakeside.proto',
  package='lakeside',
  syntax='proto2',
  serialized_pb=_b('\n\x0elakeside.proto\x12\x08lakeside\"\x14\n\x04Ping\x12\x0c\n\x04type\x18\x01 \x02(\x05\"5\n\nBulbValues\x12\x12\n\nbrightness\x18\x01 \x02(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x05\"\x9c\x01\n\tBulbState\x12\x0f\n\x07\x63ommand\x18\x01 \x02(\x05\x12$\n\x06values\x18\x02 \x01(\x0b\x32\x14.lakeside.BulbValues\x12\r\n\x05power\x18\x03 \x01(\x05\x12\x10\n\x08unknown1\x18\x04 \x01(\x05\x12%\n\x07values2\x18\x05 \x01(\x0b\x32\x14.lakeside.BulbValues\x12\x10\n\x08unknown2\x18\x06 \x01(\x05\"l\n\nBulbPacket\x12\x10\n\x08unknown1\x18\x01 \x02(\x05\x12&\n\tbulbstate\x18\x02 \x01(\x0b\x32\x13.lakeside.BulbState\x12$\n\x07\x62ulbset\x18\x03 \x01(\x0b\x32\x13.lakeside.BulbState\">\n\x08\x42ulbInfo\x12\x0c\n\x04type\x18\x01 \x02(\x05\x12$\n\x06packet\x18\x02 \x01(\x0b\x32\x14.lakeside.BulbPacket\"q\n\x0bT1012Packet\x12\x10\n\x08sequence\x18\x01 \x02(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x02(\t\x12\x1c\n\x04ping\x18\x03 \x01(\x0b\x32\x0e.lakeside.Ping\x12$\n\x08\x62ulbinfo\x18\x05 \x01(\x0b\x32\x12.lakeside.BulbInfo\"\xa6\x01\n\tT1013Info\x12\x0f\n\x07\x63ommand\x18\x01 \x02(\x05\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\r\n\x05power\x18\x03 \x01(\x05\x12$\n\x06values\x18\x04 \x01(\x0b\x32\x14.lakeside.BulbValues\x12$\n\x06\x63olors\x18\x05 \x01(\x0b\x32\x14.lakeside.T1013Color\x12\x10\n\x08unknown7\x18\x07 \x01(\x05\x12\x0c\n\x04rssi\x18\x08 \x01(\x05\"\x89\x01\n\x0cT1013Control\x12\x0f\n\x07\x63ommand\x18\x01 \x02(\x05\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12$\n\x06values\x18\x03 \x01(\x0b\x32\x14.lakeside.BulbValues\x12$\n\x06\x63olors\x18\x04 \x01(\x0b\x32\x14.lakeside.T1013Color\x12\r\n\x05power\x18\x05 \x01(\x05\"J\n\nT1013Color\x12\x0b\n\x03red\x18\x01 \x02(\x05\x12\r\n\x05green\x18\x02 \x02(\x05\x12\x0c\n\x04\x62lue\x18\x03 \x02(\x05\x12\x12\n\nbrightness\x18\x04 \x02(\x05\"|\n\nT1013State\x12\x10\n\x08unknown1\x18\x01 \x02(\x05\x12!\n\x04info\x18\x02 \x01(\x0b\x32\x13.lakeside.T1013Info\x12\'\n\x07\x63ontrol\x18\x03 \x01(\x0b\x32\x16.lakeside.T1013Control\x12\x10\n\x08unknown5\x18\x05 \x01(\x05\"C\n\rT1013BulbInfo\x12\x0c\n\x04type\x18\x01 \x02(\x05\x12$\n\x06packet\x18\x02 \x01(\x0b\x32\x14.lakeside.T1013State\"v\n\x0bT1013Packet\x12\x10\n\x08sequence\x18\x01 \x02(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x02(\t\x12\x1c\n\x04ping\x18\x03 \x01(\x0b\x32\x0e.lakeside.Ping\x12)\n\x08\x62ulbinfo\x18\x05 \x01(\x0b\x32\x17.lakeside.T1013BulbInfo\"-\n\x0bSwitchState\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x05\"e\n\x0cSwitchStatus\x12\x10\n\x08unknown1\x18\x01 \x01(\x05\x12\r\n\x05power\x18\x02 \x01(\x05\x12\x10\n\x08unknown3\x18\x03 \x01(\x05\x12\x10\n\x08unknown4\x18\x04 \x01(\x05\x12\x10\n\x08unknown5\x18\x05 \x01(\x05\"x\n\x0cSwitchPacket\x12\x10\n\x08unknown1\x18\x01 \x02(\x05\x12(\n\tswitchset\x18\x03 \x01(\x0b\x32\x15.lakeside.SwitchState\x12,\n\x0cswitchstatus\x18\x05 \x01(\x0b\x32\x16.lakeside.SwitchStatus\"B\n\nSwitchInfo\x12\x0c\n\x04type\x18\x01 \x02(\x05\x12&\n\x06packet\x18\x02 \x01(\x0b\x32\x16.lakeside.SwitchPacket\"u\n\x0bT1201Packet\x12\x10\n\x08sequence\x18\x01 \x02(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x02(\t\x12\x1c\n\x04ping\x18\x03 \x01(\x0b\x32\x0e.lakeside.Ping\x12(\n\nswitchinfo\x18\x05 \x01(\x0b\x32\x14.lakeside.SwitchInfo')
)




_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='lakeside.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.Ping.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=48,
)


_BULBVALUES = _descriptor.Descriptor(
  name='BulbValues',
  full_name='lakeside.BulbValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='brightness', full_name='lakeside.BulbValues.brightness', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='lakeside.BulbValues.temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=103,
)


_BULBSTATE = _descriptor.Descriptor(
  name='BulbState',
  full_name='lakeside.BulbState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='lakeside.BulbState.command', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='lakeside.BulbState.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='lakeside.BulbState.power', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.BulbState.unknown1', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values2', full_name='lakeside.BulbState.values2', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown2', full_name='lakeside.BulbState.unknown2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=262,
)


_BULBPACKET = _descriptor.Descriptor(
  name='BulbPacket',
  full_name='lakeside.BulbPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.BulbPacket.unknown1', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbstate', full_name='lakeside.BulbPacket.bulbstate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbset', full_name='lakeside.BulbPacket.bulbset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=372,
)


_BULBINFO = _descriptor.Descriptor(
  name='BulbInfo',
  full_name='lakeside.BulbInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.BulbInfo.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='lakeside.BulbInfo.packet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=436,
)


_T1012PACKET = _descriptor.Descriptor(
  name='T1012Packet',
  full_name='lakeside.T1012Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='lakeside.T1012Packet.sequence', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='lakeside.T1012Packet.code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='lakeside.T1012Packet.ping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbinfo', full_name='lakeside.T1012Packet.bulbinfo', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=551,
)


_T1013INFO = _descriptor.Descriptor(
  name='T1013Info',
  full_name='lakeside.T1013Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='lakeside.T1013Info.command', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='lakeside.T1013Info.color', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='lakeside.T1013Info.power', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='lakeside.T1013Info.values', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='colors', full_name='lakeside.T1013Info.colors', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown7', full_name='lakeside.T1013Info.unknown7', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rssi', full_name='lakeside.T1013Info.rssi', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=720,
)


_T1013CONTROL = _descriptor.Descriptor(
  name='T1013Control',
  full_name='lakeside.T1013Control',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='lakeside.T1013Control.command', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='lakeside.T1013Control.color', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='lakeside.T1013Control.values', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='colors', full_name='lakeside.T1013Control.colors', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='lakeside.T1013Control.power', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=860,
)


_T1013COLOR = _descriptor.Descriptor(
  name='T1013Color',
  full_name='lakeside.T1013Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='red', full_name='lakeside.T1013Color.red', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='green', full_name='lakeside.T1013Color.green', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blue', full_name='lakeside.T1013Color.blue', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='brightness', full_name='lakeside.T1013Color.brightness', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=936,
)


_T1013STATE = _descriptor.Descriptor(
  name='T1013State',
  full_name='lakeside.T1013State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.T1013State.unknown1', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='info', full_name='lakeside.T1013State.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='control', full_name='lakeside.T1013State.control', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown5', full_name='lakeside.T1013State.unknown5', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1062,
)


_T1013BULBINFO = _descriptor.Descriptor(
  name='T1013BulbInfo',
  full_name='lakeside.T1013BulbInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.T1013BulbInfo.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='lakeside.T1013BulbInfo.packet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1131,
)


_T1013PACKET = _descriptor.Descriptor(
  name='T1013Packet',
  full_name='lakeside.T1013Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='lakeside.T1013Packet.sequence', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='lakeside.T1013Packet.code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='lakeside.T1013Packet.ping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbinfo', full_name='lakeside.T1013Packet.bulbinfo', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1251,
)


_SWITCHSTATE = _descriptor.Descriptor(
  name='SwitchState',
  full_name='lakeside.SwitchState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='lakeside.SwitchState.command', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='lakeside.SwitchState.state', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1298,
)


_SWITCHSTATUS = _descriptor.Descriptor(
  name='SwitchStatus',
  full_name='lakeside.SwitchStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.SwitchStatus.unknown1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='lakeside.SwitchStatus.power', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown3', full_name='lakeside.SwitchStatus.unknown3', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown4', full_name='lakeside.SwitchStatus.unknown4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown5', full_name='lakeside.SwitchStatus.unknown5', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1300,
  serialized_end=1401,
)


_SWITCHPACKET = _descriptor.Descriptor(
  name='SwitchPacket',
  full_name='lakeside.SwitchPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.SwitchPacket.unknown1', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='switchset', full_name='lakeside.SwitchPacket.switchset', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='switchstatus', full_name='lakeside.SwitchPacket.switchstatus', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1403,
  serialized_end=1523,
)


_SWITCHINFO = _descriptor.Descriptor(
  name='SwitchInfo',
  full_name='lakeside.SwitchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.SwitchInfo.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='lakeside.SwitchInfo.packet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1525,
  serialized_end=1591,
)


_T1201PACKET = _descriptor.Descriptor(
  name='T1201Packet',
  full_name='lakeside.T1201Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='lakeside.T1201Packet.sequence', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='lakeside.T1201Packet.code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='lakeside.T1201Packet.ping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='switchinfo', full_name='lakeside.T1201Packet.switchinfo', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1593,
  serialized_end=1710,
)

_BULBSTATE.fields_by_name['values'].message_type = _BULBVALUES
_BULBSTATE.fields_by_name['values2'].message_type = _BULBVALUES
_BULBPACKET.fields_by_name['bulbstate'].message_type = _BULBSTATE
_BULBPACKET.fields_by_name['bulbset'].message_type = _BULBSTATE
_BULBINFO.fields_by_name['packet'].message_type = _BULBPACKET
_T1012PACKET.fields_by_name['ping'].message_type = _PING
_T1012PACKET.fields_by_name['bulbinfo'].message_type = _BULBINFO
_T1013INFO.fields_by_name['values'].message_type = _BULBVALUES
_T1013INFO.fields_by_name['colors'].message_type = _T1013COLOR
_T1013CONTROL.fields_by_name['values'].message_type = _BULBVALUES
_T1013CONTROL.fields_by_name['colors'].message_type = _T1013COLOR
_T1013STATE.fields_by_name['info'].message_type = _T1013INFO
_T1013STATE.fields_by_name['control'].message_type = _T1013CONTROL
_T1013BULBINFO.fields_by_name['packet'].message_type = _T1013STATE
_T1013PACKET.fields_by_name['ping'].message_type = _PING
_T1013PACKET.fields_by_name['bulbinfo'].message_type = _T1013BULBINFO
_SWITCHPACKET.fields_by_name['switchset'].message_type = _SWITCHSTATE
_SWITCHPACKET.fields_by_name['switchstatus'].message_type = _SWITCHSTATUS
_SWITCHINFO.fields_by_name['packet'].message_type = _SWITCHPACKET
_T1201PACKET.fields_by_name['ping'].message_type = _PING
_T1201PACKET.fields_by_name['switchinfo'].message_type = _SWITCHINFO
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['BulbValues'] = _BULBVALUES
DESCRIPTOR.message_types_by_name['BulbState'] = _BULBSTATE
DESCRIPTOR.message_types_by_name['BulbPacket'] = _BULBPACKET
DESCRIPTOR.message_types_by_name['BulbInfo'] = _BULBINFO
DESCRIPTOR.message_types_by_name['T1012Packet'] = _T1012PACKET
DESCRIPTOR.message_types_by_name['T1013Info'] = _T1013INFO
DESCRIPTOR.message_types_by_name['T1013Control'] = _T1013CONTROL
DESCRIPTOR.message_types_by_name['T1013Color'] = _T1013COLOR
DESCRIPTOR.message_types_by_name['T1013State'] = _T1013STATE
DESCRIPTOR.message_types_by_name['T1013BulbInfo'] = _T1013BULBINFO
DESCRIPTOR.message_types_by_name['T1013Packet'] = _T1013PACKET
DESCRIPTOR.message_types_by_name['SwitchState'] = _SWITCHSTATE
DESCRIPTOR.message_types_by_name['SwitchStatus'] = _SWITCHSTATUS
DESCRIPTOR.message_types_by_name['SwitchPacket'] = _SWITCHPACKET
DESCRIPTOR.message_types_by_name['SwitchInfo'] = _SWITCHINFO
DESCRIPTOR.message_types_by_name['T1201Packet'] = _T1201PACKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), dict(
  DESCRIPTOR = _PING,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.Ping)
  ))
_sym_db.RegisterMessage(Ping)

BulbValues = _reflection.GeneratedProtocolMessageType('BulbValues', (_message.Message,), dict(
  DESCRIPTOR = _BULBVALUES,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbValues)
  ))
_sym_db.RegisterMessage(BulbValues)

BulbState = _reflection.GeneratedProtocolMessageType('BulbState', (_message.Message,), dict(
  DESCRIPTOR = _BULBSTATE,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbState)
  ))
_sym_db.RegisterMessage(BulbState)

BulbPacket = _reflection.GeneratedProtocolMessageType('BulbPacket', (_message.Message,), dict(
  DESCRIPTOR = _BULBPACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbPacket)
  ))
_sym_db.RegisterMessage(BulbPacket)

BulbInfo = _reflection.GeneratedProtocolMessageType('BulbInfo', (_message.Message,), dict(
  DESCRIPTOR = _BULBINFO,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbInfo)
  ))
_sym_db.RegisterMessage(BulbInfo)

T1012Packet = _reflection.GeneratedProtocolMessageType('T1012Packet', (_message.Message,), dict(
  DESCRIPTOR = _T1012PACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1012Packet)
  ))
_sym_db.RegisterMessage(T1012Packet)

T1013Info = _reflection.GeneratedProtocolMessageType('T1013Info', (_message.Message,), dict(
  DESCRIPTOR = _T1013INFO,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013Info)
  ))
_sym_db.RegisterMessage(T1013Info)

T1013Control = _reflection.GeneratedProtocolMessageType('T1013Control', (_message.Message,), dict(
  DESCRIPTOR = _T1013CONTROL,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013Control)
  ))
_sym_db.RegisterMessage(T1013Control)

T1013Color = _reflection.GeneratedProtocolMessageType('T1013Color', (_message.Message,), dict(
  DESCRIPTOR = _T1013COLOR,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013Color)
  ))
_sym_db.RegisterMessage(T1013Color)

T1013State = _reflection.GeneratedProtocolMessageType('T1013State', (_message.Message,), dict(
  DESCRIPTOR = _T1013STATE,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013State)
  ))
_sym_db.RegisterMessage(T1013State)

T1013BulbInfo = _reflection.GeneratedProtocolMessageType('T1013BulbInfo', (_message.Message,), dict(
  DESCRIPTOR = _T1013BULBINFO,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013BulbInfo)
  ))
_sym_db.RegisterMessage(T1013BulbInfo)

T1013Packet = _reflection.GeneratedProtocolMessageType('T1013Packet', (_message.Message,), dict(
  DESCRIPTOR = _T1013PACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1013Packet)
  ))
_sym_db.RegisterMessage(T1013Packet)

SwitchState = _reflection.GeneratedProtocolMessageType('SwitchState', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHSTATE,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.SwitchState)
  ))
_sym_db.RegisterMessage(SwitchState)

SwitchStatus = _reflection.GeneratedProtocolMessageType('SwitchStatus', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHSTATUS,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.SwitchStatus)
  ))
_sym_db.RegisterMessage(SwitchStatus)

SwitchPacket = _reflection.GeneratedProtocolMessageType('SwitchPacket', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHPACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.SwitchPacket)
  ))
_sym_db.RegisterMessage(SwitchPacket)

SwitchInfo = _reflection.GeneratedProtocolMessageType('SwitchInfo', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHINFO,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.SwitchInfo)
  ))
_sym_db.RegisterMessage(SwitchInfo)

T1201Packet = _reflection.GeneratedProtocolMessageType('T1201Packet', (_message.Message,), dict(
  DESCRIPTOR = _T1201PACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.T1201Packet)
  ))
_sym_db.RegisterMessage(T1201Packet)


# @@protoc_insertion_point(module_scope)
